@@ -1012,3 +1012,19 @@ void * __init probe_ksize(void)
 }
 
 #endif
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(5, 8, 0)
+
+/**
+ * probe_copy_to_kernel_nofault - Find address of "copy_to_kernel_nofault()".
+ *
+ * Returns address of copy_to_kernel_nofault() on success, NULL otherwise.
+ */
+void * __init probe_copy_to_kernel_nofault(void)
+{
+	void *ptr = probe_find_symbol(" copy_to_kernel_nofault\n");
+
+	return check_function_address(ptr, "copy_to_kernel_nofault");
+}
+
+#endif
